@@ -1,7 +1,7 @@
 #' @title Removes samples with peaks equal to or less than a specified threshold value.
 #'
 #' @description Removes samples with a peak number less than a specified value.
-#' @param x Binary matrix (consolidated or original).
+#' @param x Binary matrix - consolidated or original.
 #' @param thresh Peak threshold value for removal.
 #'
 #' @return Filtered dataset, and either the row name/s or row number/s of samples that were removed.
@@ -40,10 +40,10 @@ peak.remove = function(x, thresh) {
 
    # names(x_removed)[1]="Group"
 
-    message(c("Number of samples removed: ", nrow(x_removed)))
+    writeLines(c("Number of samples removed: ", nrow(x_removed)))
 
     if(nrow(x_removed) > 0)
-    message(c("This was/these were: ", rownames(x_removed)))
+    writeLines(c("This was/these were: ", rownames(x_removed)))
 
     return(x_keep)
   }
